# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iam/v1/refresh_token_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.iam.v1 import refresh_token_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_refresh__token__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/iam/v1/refresh_token_service.proto\x12\x13yandex.cloud.iam.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a\'yandex/cloud/iam/v1/refresh_token.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"K\n\x1aRevokeRefreshTokenMetadata\x12\x12\n\nsubject_id\x18\x01 \x01(\t\x12\x19\n\x11refresh_token_ids\x18\x02 \x03(\t\"\x9f\x01\n\x18ListRefreshTokensRequest\x12\x1c\n\nsubject_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x04 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x06 \x01(\tB\n\x8a\xc8\x31\x06<=1000J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\"o\n\x19ListRefreshTokensResponse\x12\x39\n\x0erefresh_tokens\x18\x01 \x03(\x0b\x32!.yandex.cloud.iam.v1.RefreshToken\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xb2\x01\n\x19RevokeRefreshTokenRequest\x12$\n\x10refresh_token_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12#\n\rrefresh_token\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=1000H\x00\x12:\n\rrevoke_filter\x18\x03 \x01(\x0b\x32!.yandex.cloud.iam.v1.RevokeFilterH\x00\x42\x0e\n\x06\x66ilter\x12\x04\xc0\xc1\x31\x01\"y\n\x0cRevokeFilter\x12\x1b\n\tclient_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1c\n\nsubject_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12(\n\x14\x63lient_instance_info\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000J\x04\x08\x01\x10\x02\"7\n\x1aRevokeRefreshTokenResponse\x12\x19\n\x11refresh_token_ids\x18\x01 \x03(\t2\xdf\x02\n\x13RefreshTokenService\x12\x84\x01\n\x04List\x12-.yandex.cloud.iam.v1.ListRefreshTokensRequest\x1a..yandex.cloud.iam.v1.ListRefreshTokensResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/iam/v1/refreshTokens\x12\xc0\x01\n\x06Revoke\x12..yandex.cloud.iam.v1.RevokeRefreshTokenRequest\x1a!.yandex.cloud.operation.Operation\"c\xb2\xd2*8\n\x1aRevokeRefreshTokenMetadata\x12\x1aRevokeRefreshTokenResponse\x82\xd3\xe4\x93\x02!\"\x1c/iam/v1/refreshTokens:revoke:\x01*BV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.refresh_token_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _LISTREFRESHTOKENSREQUEST.fields_by_name['subject_id']._options = None
  _LISTREFRESHTOKENSREQUEST.fields_by_name['subject_id']._serialized_options = b'\212\3101\004<=50'
  _LISTREFRESHTOKENSREQUEST.fields_by_name['page_size']._options = None
  _LISTREFRESHTOKENSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTREFRESHTOKENSREQUEST.fields_by_name['page_token']._options = None
  _LISTREFRESHTOKENSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _LISTREFRESHTOKENSREQUEST.fields_by_name['filter']._options = None
  _LISTREFRESHTOKENSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _REVOKEREFRESHTOKENREQUEST.oneofs_by_name['filter']._options = None
  _REVOKEREFRESHTOKENREQUEST.oneofs_by_name['filter']._serialized_options = b'\300\3011\001'
  _REVOKEREFRESHTOKENREQUEST.fields_by_name['refresh_token_id']._options = None
  _REVOKEREFRESHTOKENREQUEST.fields_by_name['refresh_token_id']._serialized_options = b'\212\3101\004<=50'
  _REVOKEREFRESHTOKENREQUEST.fields_by_name['refresh_token']._options = None
  _REVOKEREFRESHTOKENREQUEST.fields_by_name['refresh_token']._serialized_options = b'\212\3101\006<=1000'
  _REVOKEFILTER.fields_by_name['client_id']._options = None
  _REVOKEFILTER.fields_by_name['client_id']._serialized_options = b'\212\3101\004<=50'
  _REVOKEFILTER.fields_by_name['subject_id']._options = None
  _REVOKEFILTER.fields_by_name['subject_id']._serialized_options = b'\212\3101\004<=50'
  _REVOKEFILTER.fields_by_name['client_instance_info']._options = None
  _REVOKEFILTER.fields_by_name['client_instance_info']._serialized_options = b'\212\3101\006<=1000'
  _REFRESHTOKENSERVICE.methods_by_name['List']._options = None
  _REFRESHTOKENSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\027\022\025/iam/v1/refreshTokens'
  _REFRESHTOKENSERVICE.methods_by_name['Revoke']._options = None
  _REFRESHTOKENSERVICE.methods_by_name['Revoke']._serialized_options = b'\262\322*8\n\032RevokeRefreshTokenMetadata\022\032RevokeRefreshTokenResponse\202\323\344\223\002!\"\034/iam/v1/refreshTokens:revoke:\001*'
  _globals['_REVOKEREFRESHTOKENMETADATA']._serialized_start=248
  _globals['_REVOKEREFRESHTOKENMETADATA']._serialized_end=323
  _globals['_LISTREFRESHTOKENSREQUEST']._serialized_start=326
  _globals['_LISTREFRESHTOKENSREQUEST']._serialized_end=485
  _globals['_LISTREFRESHTOKENSRESPONSE']._serialized_start=487
  _globals['_LISTREFRESHTOKENSRESPONSE']._serialized_end=598
  _globals['_REVOKEREFRESHTOKENREQUEST']._serialized_start=601
  _globals['_REVOKEREFRESHTOKENREQUEST']._serialized_end=779
  _globals['_REVOKEFILTER']._serialized_start=781
  _globals['_REVOKEFILTER']._serialized_end=902
  _globals['_REVOKEREFRESHTOKENRESPONSE']._serialized_start=904
  _globals['_REVOKEREFRESHTOKENRESPONSE']._serialized_end=959
  _globals['_REFRESHTOKENSERVICE']._serialized_start=962
  _globals['_REFRESHTOKENSERVICE']._serialized_end=1313
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.compute.v1.filesystem_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetFilesystemRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILESYSTEM_ID_FIELD_NUMBER: builtins.int
    filesystem_id: builtins.str
    """ID of the filesystem to return.

    To get the filesystem ID, make a [FilesystemService.List] request.
    """
    def __init__(
        self,
        *,
        filesystem_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filesystem_id", b"filesystem_id"]) -> None: ...

global___GetFilesystemRequest = GetFilesystemRequest

@typing.final
class ListFilesystemsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list filesystems in.

    To get the folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`,
    the service returns a [ListFilesystemsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListFilesystemsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression consists of one or more conditions united by `AND` operator: `<condition1> [AND <condition2> [<...> AND <conditionN>]]`.

    Each condition has the form `<field> <operator> <value>`, where:
    1. `<field>` is the field name. Currently you can use filtering only on the limited number of fields.
    2. `<operator>` is a logical operator, one of `=`, `!=`, `IN`, `NOT IN`.
    3. `<value>` represents a value.
    String values should be written in double (`"`) or single (`'`) quotes. C-style escape sequences are supported (`\\"` turns to `"`, `\\'` to `'`, `\\\\` to backslash).
    """
    order_by: builtins.str
    """By which column the listing should be ordered and in which direction,
    format is "createdAt desc". "id asc" if omitted.
    The default sorting order is ascending
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
        order_by: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListFilesystemsRequest = ListFilesystemsRequest

@typing.final
class ListFilesystemsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILESYSTEMS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListFilesystemsRequest.page_size], use `next_page_token` as the value
    for the [ListFilesystemsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def filesystems(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.compute.v1.filesystem_pb2.Filesystem]:
        """List of filesystems in the specified folder."""

    def __init__(
        self,
        *,
        filesystems: collections.abc.Iterable[yandex.cloud.compute.v1.filesystem_pb2.Filesystem] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filesystems", b"filesystems", "next_page_token", b"next_page_token"]) -> None: ...

global___ListFilesystemsResponse = ListFilesystemsResponse

@typing.final
class CreateFilesystemRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TYPE_ID_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    BLOCK_SIZE_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a filesystem in.

    To get the folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the filesystem. The name must be unique within the folder."""
    description: builtins.str
    """Description of the filesystem."""
    type_id: builtins.str
    """ID of the filesystem type.

    To get a list of available filesystem types, make a [yandex.cloud.compute.v1.DiskTypeService.List] request.

    The filesystem type cannot be updated after the filesystem creation.
    """
    zone_id: builtins.str
    """ID of the availability zone where the filesystem resides.

    To get a list of available zones, make a [yandex.cloud.compute.v1.ZoneService.List] request.

    A filesystem can be attached only to virtual machines residing in the same availability zone.
    The filesystem availability zone cannot be updated after the filesystem creation.
    """
    size: builtins.int
    """Size of the filesystem, specified in bytes.

    The size of the filesystem cannot be updated after the filesystem creation.
    """
    block_size: builtins.int
    """Block size used for the filesystem, specified in bytes.

    The block size cannot be updated after the filesystem creation.

    Default value: 4096.
    """
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Filesystem labels as `key:value` pairs.
        For details about the concept, see [documentation](/docs/overview/concepts/services#labels).
        """

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        type_id: builtins.str = ...,
        zone_id: builtins.str = ...,
        size: builtins.int = ...,
        block_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["block_size", b"block_size", "description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "size", b"size", "type_id", b"type_id", "zone_id", b"zone_id"]) -> None: ...

global___CreateFilesystemRequest = CreateFilesystemRequest

@typing.final
class CreateFilesystemMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILESYSTEM_ID_FIELD_NUMBER: builtins.int
    filesystem_id: builtins.str
    """ID of the filesystem that is being created."""
    def __init__(
        self,
        *,
        filesystem_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filesystem_id", b"filesystem_id"]) -> None: ...

global___CreateFilesystemMetadata = CreateFilesystemMetadata

@typing.final
class UpdateFilesystemRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FILESYSTEM_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    filesystem_id: builtins.str
    """ID of the filesystem to update.

    To get the filesystem ID, make a [FilesystemService.List] request.
    """
    name: builtins.str
    """New name of the filesystem. The name must be unique within the folder."""
    description: builtins.str
    """New description of the filesystem."""
    size: builtins.int
    """Size of the filesystem, specified in bytes."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the filesystem should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """New filesystem labels as `key:value` pairs.
        For details about the concept, see [documentation](/docs/overview/concepts/services#labels).

        Existing set of labels is completely replaced by the provided set, so if you just want
        to add or remove a label:
        1. Get the current set of labels with a [FilesystemService.Get] request.
        2. Add or remove a label in this set.
        3. Send the new set in this field.
        """

    def __init__(
        self,
        *,
        filesystem_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        size: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "filesystem_id", b"filesystem_id", "labels", b"labels", "name", b"name", "size", b"size", "update_mask", b"update_mask"]) -> None: ...

global___UpdateFilesystemRequest = UpdateFilesystemRequest

@typing.final
class UpdateFilesystemMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILESYSTEM_ID_FIELD_NUMBER: builtins.int
    filesystem_id: builtins.str
    """ID of the filesystem that is being updated."""
    def __init__(
        self,
        *,
        filesystem_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filesystem_id", b"filesystem_id"]) -> None: ...

global___UpdateFilesystemMetadata = UpdateFilesystemMetadata

@typing.final
class DeleteFilesystemRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILESYSTEM_ID_FIELD_NUMBER: builtins.int
    filesystem_id: builtins.str
    """ID of the filesystem to delete.

    To get the filesystem ID, make a [FilesystemService.List] request.
    """
    def __init__(
        self,
        *,
        filesystem_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filesystem_id", b"filesystem_id"]) -> None: ...

global___DeleteFilesystemRequest = DeleteFilesystemRequest

@typing.final
class DeleteFilesystemMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILESYSTEM_ID_FIELD_NUMBER: builtins.int
    filesystem_id: builtins.str
    """ID of the filesystem that is being deleted."""
    def __init__(
        self,
        *,
        filesystem_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filesystem_id", b"filesystem_id"]) -> None: ...

global___DeleteFilesystemMetadata = DeleteFilesystemMetadata

@typing.final
class ListFilesystemOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILESYSTEM_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    filesystem_id: builtins.str
    """ID of the filesystem to list operations for.

    To get the filesystem ID, make a [FilesystemService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListFilesystemOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListFilesystemOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        filesystem_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filesystem_id", b"filesystem_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListFilesystemOperationsRequest = ListFilesystemOperationsRequest

@typing.final
class ListFilesystemOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListFilesystemOperationsRequest.page_size], use `next_page_token` as the value
    for the [ListFilesystemOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified filesystem."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListFilesystemOperationsResponse = ListFilesystemOperationsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/apploadbalancer/v1/load_balancer.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.apploadbalancer.v1 import logging_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_logging__pb2
from yandex.cloud.apploadbalancer.v1 import target_group_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_target__group__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/apploadbalancer/v1/load_balancer.proto\x12\x1fyandex.cloud.apploadbalancer.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\x1a-yandex/cloud/apploadbalancer/v1/logging.proto\x1a\x32yandex/cloud/apploadbalancer/v1/target_group.proto\"\xa7\x06\n\x0cLoadBalancer\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x11\n\tfolder_id\x18\x04 \x01(\t\x12I\n\x06labels\x18\x05 \x03(\x0b\x32\x39.yandex.cloud.apploadbalancer.v1.LoadBalancer.LabelsEntry\x12\x44\n\x06status\x18\x06 \x01(\x0e\x32\x34.yandex.cloud.apploadbalancer.v1.LoadBalancer.Status\x12\x11\n\tregion_id\x18\x07 \x01(\t\x12\x12\n\nnetwork_id\x18\x08 \x01(\t\x12<\n\tlisteners\x18\t \x03(\x0b\x32).yandex.cloud.apploadbalancer.v1.Listener\x12L\n\x11\x61llocation_policy\x18\n \x01(\x0b\x32\x31.yandex.cloud.apploadbalancer.v1.AllocationPolicy\x12\x14\n\x0clog_group_id\x18\x0b \x01(\t\x12\x1a\n\x12security_group_ids\x18\x0c \x03(\t\x12.\n\ncreated_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12K\n\x11\x61uto_scale_policy\x18\x0e \x01(\x0b\x32\x30.yandex.cloud.apploadbalancer.v1.AutoScalePolicy\x12@\n\x0blog_options\x18\x0f \x01(\x0b\x32+.yandex.cloud.apploadbalancer.v1.LogOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"q\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0c\n\x08STARTING\x10\x02\x12\n\n\x06\x41\x43TIVE\x10\x03\x12\x0c\n\x08STOPPING\x10\x04\x12\x0b\n\x07STOPPED\x10\x05\x12\x0c\n\x08\x44\x45LETING\x10\x06\"\x9f\x02\n\x07\x41\x64\x64ress\x12U\n\x15\x65xternal_ipv4_address\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.apploadbalancer.v1.ExternalIpv4AddressH\x00\x12U\n\x15internal_ipv4_address\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.apploadbalancer.v1.InternalIpv4AddressH\x00\x12U\n\x15\x65xternal_ipv6_address\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.apploadbalancer.v1.ExternalIpv6AddressH\x00\x42\x0f\n\x07\x61\x64\x64ress\x12\x04\xc0\xc1\x31\x01\"&\n\x13\x45xternalIpv4Address\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"9\n\x13InternalIpv4Address\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x11\n\tsubnet_id\x18\x02 \x01(\t\"&\n\x13\x45xternalIpv6Address\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"M\n\x08Location\x12\x15\n\x07zone_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tsubnet_id\x18\x02 \x01(\t\x12\x17\n\x0f\x64isable_traffic\x18\x03 \x01(\x08\"]\n\x10\x41llocationPolicy\x12I\n\tlocations\x18\x01 \x03(\x0b\x32).yandex.cloud.apploadbalancer.v1.LocationB\x0b\x82\xc8\x31\x03>=1\x90\xc8\x31\x01\"\xad\x02\n\x08Listener\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12<\n\tendpoints\x18\x02 \x03(\x0b\x32).yandex.cloud.apploadbalancer.v1.Endpoint\x12=\n\x04http\x18\x03 \x01(\x0b\x32-.yandex.cloud.apploadbalancer.v1.HttpListenerH\x00\x12;\n\x03tls\x18\x04 \x01(\x0b\x32,.yandex.cloud.apploadbalancer.v1.TlsListenerH\x00\x12\x41\n\x06stream\x18\x05 \x01(\x0b\x32/.yandex.cloud.apploadbalancer.v1.StreamListenerH\x00\x42\x10\n\x08listener\x12\x04\xc0\xc1\x31\x01\"q\n\x08\x45ndpoint\x12\x43\n\taddresses\x18\x01 \x03(\x0b\x32(.yandex.cloud.apploadbalancer.v1.AddressB\x06\x82\xc8\x31\x02>0\x12 \n\x05ports\x18\x02 \x03(\x03\x42\x11\xfa\xc7\x31\x07\x31-65535\x82\xc8\x31\x02>0\"\x8c\x01\n\x0cHttpListener\x12=\n\x07handler\x18\x01 \x01(\x0b\x32,.yandex.cloud.apploadbalancer.v1.HttpHandler\x12=\n\tredirects\x18\x02 \x01(\x0b\x32*.yandex.cloud.apploadbalancer.v1.Redirects\"\x9a\x01\n\x0bTlsListener\x12J\n\x0f\x64\x65\x66\x61ult_handler\x18\x01 \x01(\x0b\x32+.yandex.cloud.apploadbalancer.v1.TlsHandlerB\x04\xe8\xc7\x31\x01\x12?\n\x0csni_handlers\x18\x02 \x03(\x0b\x32).yandex.cloud.apploadbalancer.v1.SniMatch\"W\n\x0eStreamListener\x12\x45\n\x07handler\x18\x01 \x01(\x0b\x32..yandex.cloud.apploadbalancer.v1.StreamHandlerB\x04\xe8\xc7\x31\x01\".\n\x0cHttp2Options\x12\x1e\n\x16max_concurrent_streams\x18\x01 \x01(\x03\"/\n\rStreamHandler\x12\x1e\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\xb6\x01\n\x0bHttpHandler\x12\x16\n\x0ehttp_router_id\x18\x01 \x01(\t\x12\x46\n\rhttp2_options\x18\x02 \x01(\x0b\x32-.yandex.cloud.apploadbalancer.v1.Http2OptionsH\x00\x12\x16\n\x0c\x61llow_http10\x18\x03 \x01(\x08H\x00\x12\x1a\n\x12rewrite_request_id\x18\x04 \x01(\x08\x42\x13\n\x11protocol_settings\"\"\n\tRedirects\x12\x15\n\rhttp_to_https\x18\x01 \x01(\x08\"\x80\x01\n\x08SniMatch\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1c\n\x0cserver_names\x18\x02 \x03(\tB\x06\x82\xc8\x31\x02>0\x12\x42\n\x07handler\x18\x03 \x01(\x0b\x32+.yandex.cloud.apploadbalancer.v1.TlsHandlerB\x04\xe8\xc7\x31\x01\"\xce\x01\n\nTlsHandler\x12\x44\n\x0chttp_handler\x18\x02 \x01(\x0b\x32,.yandex.cloud.apploadbalancer.v1.HttpHandlerH\x00\x12H\n\x0estream_handler\x18\x04 \x01(\x0b\x32..yandex.cloud.apploadbalancer.v1.StreamHandlerH\x00\x12\x1f\n\x0f\x63\x65rtificate_ids\x18\x03 \x03(\tB\x06\x82\xc8\x31\x02>0B\x0f\n\x07handler\x12\x04\xc0\xc1\x31\x01\"\x8c\x04\n\x0bTargetState\x12N\n\x06status\x18\x01 \x01(\x0b\x32>.yandex.cloud.apploadbalancer.v1.TargetState.HealthcheckStatus\x12=\n\x06target\x18\x02 \x01(\x0b\x32\'.yandex.cloud.apploadbalancer.v1.TargetB\x04\xe8\xc7\x31\x01\x1an\n\x11HealthcheckStatus\x12Y\n\rzone_statuses\x18\x01 \x03(\x0b\x32\x42.yandex.cloud.apploadbalancer.v1.TargetState.ZoneHealthcheckStatus\x1a\x8d\x01\n\x15ZoneHealthcheckStatus\x12\x15\n\x07zone_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x43\n\x06status\x18\x02 \x01(\x0e\x32\x33.yandex.cloud.apploadbalancer.v1.TargetState.Status\x12\x18\n\x10\x66\x61iled_active_hc\x18\x03 \x01(\x08\"n\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07HEALTHY\x10\x01\x12\x15\n\x11PARTIALLY_HEALTHY\x10\x02\x12\r\n\tUNHEALTHY\x10\x03\x12\x0c\n\x08\x44RAINING\x10\x04\x12\x0b\n\x07TIMEOUT\x10\x05\"R\n\x0f\x41utoScalePolicy\x12!\n\rmin_zone_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1c\n\x08max_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000Bz\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.apploadbalancer.v1.load_balancer_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancer'
  _LOADBALANCER_LABELSENTRY._options = None
  _LOADBALANCER_LABELSENTRY._serialized_options = b'8\001'
  _ADDRESS.oneofs_by_name['address']._options = None
  _ADDRESS.oneofs_by_name['address']._serialized_options = b'\300\3011\001'
  _LOCATION.fields_by_name['zone_id']._options = None
  _LOCATION.fields_by_name['zone_id']._serialized_options = b'\350\3071\001'
  _ALLOCATIONPOLICY.fields_by_name['locations']._options = None
  _ALLOCATIONPOLICY.fields_by_name['locations']._serialized_options = b'\202\3101\003>=1\220\3101\001'
  _LISTENER.oneofs_by_name['listener']._options = None
  _LISTENER.oneofs_by_name['listener']._serialized_options = b'\300\3011\001'
  _LISTENER.fields_by_name['name']._options = None
  _LISTENER.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _ENDPOINT.fields_by_name['addresses']._options = None
  _ENDPOINT.fields_by_name['addresses']._serialized_options = b'\202\3101\002>0'
  _ENDPOINT.fields_by_name['ports']._options = None
  _ENDPOINT.fields_by_name['ports']._serialized_options = b'\372\3071\0071-65535\202\3101\002>0'
  _TLSLISTENER.fields_by_name['default_handler']._options = None
  _TLSLISTENER.fields_by_name['default_handler']._serialized_options = b'\350\3071\001'
  _STREAMLISTENER.fields_by_name['handler']._options = None
  _STREAMLISTENER.fields_by_name['handler']._serialized_options = b'\350\3071\001'
  _STREAMHANDLER.fields_by_name['backend_group_id']._options = None
  _STREAMHANDLER.fields_by_name['backend_group_id']._serialized_options = b'\350\3071\001'
  _SNIMATCH.fields_by_name['name']._options = None
  _SNIMATCH.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _SNIMATCH.fields_by_name['server_names']._options = None
  _SNIMATCH.fields_by_name['server_names']._serialized_options = b'\202\3101\002>0'
  _SNIMATCH.fields_by_name['handler']._options = None
  _SNIMATCH.fields_by_name['handler']._serialized_options = b'\350\3071\001'
  _TLSHANDLER.oneofs_by_name['handler']._options = None
  _TLSHANDLER.oneofs_by_name['handler']._serialized_options = b'\300\3011\001'
  _TLSHANDLER.fields_by_name['certificate_ids']._options = None
  _TLSHANDLER.fields_by_name['certificate_ids']._serialized_options = b'\202\3101\002>0'
  _TARGETSTATE_ZONEHEALTHCHECKSTATUS.fields_by_name['zone_id']._options = None
  _TARGETSTATE_ZONEHEALTHCHECKSTATUS.fields_by_name['zone_id']._serialized_options = b'\350\3071\001'
  _TARGETSTATE.fields_by_name['target']._options = None
  _TARGETSTATE.fields_by_name['target']._serialized_options = b'\350\3071\001'
  _AUTOSCALEPOLICY.fields_by_name['min_zone_size']._options = None
  _AUTOSCALEPOLICY.fields_by_name['min_zone_size']._serialized_options = b'\372\3071\0060-1000'
  _AUTOSCALEPOLICY.fields_by_name['max_size']._options = None
  _AUTOSCALEPOLICY.fields_by_name['max_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LOADBALANCER']._serialized_start=252
  _globals['_LOADBALANCER']._serialized_end=1059
  _globals['_LOADBALANCER_LABELSENTRY']._serialized_start=899
  _globals['_LOADBALANCER_LABELSENTRY']._serialized_end=944
  _globals['_LOADBALANCER_STATUS']._serialized_start=946
  _globals['_LOADBALANCER_STATUS']._serialized_end=1059
  _globals['_ADDRESS']._serialized_start=1062
  _globals['_ADDRESS']._serialized_end=1349
  _globals['_EXTERNALIPV4ADDRESS']._serialized_start=1351
  _globals['_EXTERNALIPV4ADDRESS']._serialized_end=1389
  _globals['_INTERNALIPV4ADDRESS']._serialized_start=1391
  _globals['_INTERNALIPV4ADDRESS']._serialized_end=1448
  _globals['_EXTERNALIPV6ADDRESS']._serialized_start=1450
  _globals['_EXTERNALIPV6ADDRESS']._serialized_end=1488
  _globals['_LOCATION']._serialized_start=1490
  _globals['_LOCATION']._serialized_end=1567
  _globals['_ALLOCATIONPOLICY']._serialized_start=1569
  _globals['_ALLOCATIONPOLICY']._serialized_end=1662
  _globals['_LISTENER']._serialized_start=1665
  _globals['_LISTENER']._serialized_end=1966
  _globals['_ENDPOINT']._serialized_start=1968
  _globals['_ENDPOINT']._serialized_end=2081
  _globals['_HTTPLISTENER']._serialized_start=2084
  _globals['_HTTPLISTENER']._serialized_end=2224
  _globals['_TLSLISTENER']._serialized_start=2227
  _globals['_TLSLISTENER']._serialized_end=2381
  _globals['_STREAMLISTENER']._serialized_start=2383
  _globals['_STREAMLISTENER']._serialized_end=2470
  _globals['_HTTP2OPTIONS']._serialized_start=2472
  _globals['_HTTP2OPTIONS']._serialized_end=2518
  _globals['_STREAMHANDLER']._serialized_start=2520
  _globals['_STREAMHANDLER']._serialized_end=2567
  _globals['_HTTPHANDLER']._serialized_start=2570
  _globals['_HTTPHANDLER']._serialized_end=2752
  _globals['_REDIRECTS']._serialized_start=2754
  _globals['_REDIRECTS']._serialized_end=2788
  _globals['_SNIMATCH']._serialized_start=2791
  _globals['_SNIMATCH']._serialized_end=2919
  _globals['_TLSHANDLER']._serialized_start=2922
  _globals['_TLSHANDLER']._serialized_end=3128
  _globals['_TARGETSTATE']._serialized_start=3131
  _globals['_TARGETSTATE']._serialized_end=3655
  _globals['_TARGETSTATE_HEALTHCHECKSTATUS']._serialized_start=3289
  _globals['_TARGETSTATE_HEALTHCHECKSTATUS']._serialized_end=3399
  _globals['_TARGETSTATE_ZONEHEALTHCHECKSTATUS']._serialized_start=3402
  _globals['_TARGETSTATE_ZONEHEALTHCHECKSTATUS']._serialized_end=3543
  _globals['_TARGETSTATE_STATUS']._serialized_start=3545
  _globals['_TARGETSTATE_STATUS']._serialized_end=3655
  _globals['_AUTOSCALEPOLICY']._serialized_start=3657
  _globals['_AUTOSCALEPOLICY']._serialized_end=3739
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/eventrouter/v1/connector_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.serverless.eventrouter.v1 import connector_pb2 as yandex_dot_cloud_dot_serverless_dot_eventrouter_dot_v1_dot_connector__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>yandex/cloud/serverless/eventrouter/v1/connector_service.proto\x12&yandex.cloud.serverless.eventrouter.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a\x36yandex/cloud/serverless/eventrouter/v1/connector.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"1\n\x13GetConnectorRequest\x12\x1a\n\x0c\x63onnector_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8b\x01\n\x15ListConnectorsRequest\x12\x10\n\x06\x62us_id\x18\x01 \x01(\tH\x00\x12\x13\n\tfolder_id\x18\x02 \x01(\tH\x00\x12\x11\n\tpage_size\x18\x03 \x01(\x03\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x05 \x01(\tB\x14\n\x0c\x63ontainer_id\x12\x04\xc0\xc1\x31\x01\"x\n\x16ListConnectorsResponse\x12\x45\n\nconnectors\x18\x01 \x03(\x0b\x32\x31.yandex.cloud.serverless.eventrouter.v1.Connector\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa5\x03\n\x16\x43reateConnectorRequest\x12\x14\n\x06\x62us_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x97\x01\n\x06labels\x18\x04 \x03(\x0b\x32J.yandex.cloud.serverless.eventrouter.v1.CreateConnectorRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12>\n\x06source\x18\x05 \x01(\x0b\x32..yandex.cloud.serverless.eventrouter.v1.Source\x12\x1b\n\x13\x64\x65letion_protection\x18\x06 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"?\n\x17\x43reateConnectorMetadata\x12\x14\n\x0c\x63onnector_id\x18\x01 \x01(\t\x12\x0e\n\x06\x62us_id\x18\x02 \x01(\t\"\x9c\x03\n\x16UpdateConnectorRequest\x12\x1a\n\x0c\x63onnector_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x97\x01\n\x06labels\x18\x05 \x03(\x0b\x32J.yandex.cloud.serverless.eventrouter.v1.UpdateConnectorRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x1b\n\x13\x64\x65letion_protection\x18\x06 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"5\n\x17UpdateConnectorMetadata\x12\x1a\n\x0c\x63onnector_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"4\n\x16\x44\x65leteConnectorRequest\x12\x1a\n\x0c\x63onnector_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"5\n\x17\x44\x65leteConnectorMetadata\x12\x1a\n\x0c\x63onnector_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x96\x01\n\x1eListConnectorOperationsRequest\x12\x1a\n\x0c\x63onnector_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"q\n\x1fListConnectorOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x15StartConnectorRequest\x12\x1a\n\x0c\x63onnector_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"4\n\x16StartConnectorMetadata\x12\x1a\n\x0c\x63onnector_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"2\n\x14StopConnectorRequest\x12\x1a\n\x0c\x63onnector_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"3\n\x15StopConnectorMetadata\x12\x1a\n\x0c\x63onnector_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x32\xf8\x11\n\x10\x43onnectorService\x12\xa8\x01\n\x03Get\x12;.yandex.cloud.serverless.eventrouter.v1.GetConnectorRequest\x1a\x31.yandex.cloud.serverless.eventrouter.v1.Connector\"1\x82\xd3\xe4\x93\x02+\x12)/eventrouter/v1/connectors/{connector_id}\x12\xa9\x01\n\x04List\x12=.yandex.cloud.serverless.eventrouter.v1.ListConnectorsRequest\x1a>.yandex.cloud.serverless.eventrouter.v1.ListConnectorsResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/eventrouter/v1/connectors\x12\xba\x01\n\x06\x43reate\x12>.yandex.cloud.serverless.eventrouter.v1.CreateConnectorRequest\x1a!.yandex.cloud.operation.Operation\"M\xb2\xd2*$\n\x17\x43reateConnectorMetadata\x12\tConnector\x82\xd3\xe4\x93\x02\x1f\"\x1a/eventrouter/v1/connectors:\x01*\x12\xc9\x01\n\x06Update\x12>.yandex.cloud.serverless.eventrouter.v1.UpdateConnectorRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2*$\n\x17UpdateConnectorMetadata\x12\tConnector\x82\xd3\xe4\x93\x02.2)/eventrouter/v1/connectors/{connector_id}:\x01*\x12\xd2\x01\n\x06\x44\x65lete\x12>.yandex.cloud.serverless.eventrouter.v1.DeleteConnectorRequest\x1a!.yandex.cloud.operation.Operation\"e\xb2\xd2*0\n\x17\x44\x65leteConnectorMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02+*)/eventrouter/v1/connectors/{connector_id}\x12\xd5\x01\n\x05Start\x12=.yandex.cloud.serverless.eventrouter.v1.StartConnectorRequest\x1a!.yandex.cloud.operation.Operation\"j\xb2\xd2*/\n\x16StartConnectorMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x31\"//eventrouter/v1/connectors/{connector_id}:start\x12\xd1\x01\n\x04Stop\x12<.yandex.cloud.serverless.eventrouter.v1.StopConnectorRequest\x1a!.yandex.cloud.operation.Operation\"h\xb2\xd2*.\n\x15StopConnectorMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x30\"./eventrouter/v1/connectors/{connector_id}:stop\x12\xba\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"C\x82\xd3\xe4\x93\x02=\x12;/eventrouter/v1/connectors/{resource_id}:listAccessBindings\x12\xea\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x82\x01\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02?\":/eventrouter/v1/connectors/{resource_id}:setAccessBindings:\x01*\x12\xf6\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x88\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x42\x32=/eventrouter/v1/connectors/{resource_id}:updateAccessBindings:\x01*\x12\xdf\x01\n\x0eListOperations\x12\x46.yandex.cloud.serverless.eventrouter.v1.ListConnectorOperationsRequest\x1aG.yandex.cloud.serverless.eventrouter.v1.ListConnectorOperationsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/eventrouter/v1/connectors/{connector_id}/operationsB\x8b\x01\n*yandex.cloud.api.serverless.eventrouter.v1B\x05PERCSZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/eventrouter/v1;eventrouterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.eventrouter.v1.connector_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*yandex.cloud.api.serverless.eventrouter.v1B\005PERCSZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/eventrouter/v1;eventrouter'
  _GETCONNECTORREQUEST.fields_by_name['connector_id']._options = None
  _GETCONNECTORREQUEST.fields_by_name['connector_id']._serialized_options = b'\350\3071\001'
  _LISTCONNECTORSREQUEST.oneofs_by_name['container_id']._options = None
  _LISTCONNECTORSREQUEST.oneofs_by_name['container_id']._serialized_options = b'\300\3011\001'
  _CREATECONNECTORREQUEST_LABELSENTRY._options = None
  _CREATECONNECTORREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATECONNECTORREQUEST.fields_by_name['bus_id']._options = None
  _CREATECONNECTORREQUEST.fields_by_name['bus_id']._serialized_options = b'\350\3071\001'
  _CREATECONNECTORREQUEST.fields_by_name['name']._options = None
  _CREATECONNECTORREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _CREATECONNECTORREQUEST.fields_by_name['description']._options = None
  _CREATECONNECTORREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATECONNECTORREQUEST.fields_by_name['labels']._options = None
  _CREATECONNECTORREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _UPDATECONNECTORREQUEST_LABELSENTRY._options = None
  _UPDATECONNECTORREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATECONNECTORREQUEST.fields_by_name['connector_id']._options = None
  _UPDATECONNECTORREQUEST.fields_by_name['connector_id']._serialized_options = b'\350\3071\001'
  _UPDATECONNECTORREQUEST.fields_by_name['name']._options = None
  _UPDATECONNECTORREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _UPDATECONNECTORREQUEST.fields_by_name['description']._options = None
  _UPDATECONNECTORREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATECONNECTORREQUEST.fields_by_name['labels']._options = None
  _UPDATECONNECTORREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _UPDATECONNECTORMETADATA.fields_by_name['connector_id']._options = None
  _UPDATECONNECTORMETADATA.fields_by_name['connector_id']._serialized_options = b'\350\3071\001'
  _DELETECONNECTORREQUEST.fields_by_name['connector_id']._options = None
  _DELETECONNECTORREQUEST.fields_by_name['connector_id']._serialized_options = b'\350\3071\001'
  _DELETECONNECTORMETADATA.fields_by_name['connector_id']._options = None
  _DELETECONNECTORMETADATA.fields_by_name['connector_id']._serialized_options = b'\350\3071\001'
  _LISTCONNECTOROPERATIONSREQUEST.fields_by_name['connector_id']._options = None
  _LISTCONNECTOROPERATIONSREQUEST.fields_by_name['connector_id']._serialized_options = b'\350\3071\001'
  _LISTCONNECTOROPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTCONNECTOROPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTCONNECTOROPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTCONNECTOROPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCONNECTOROPERATIONSREQUEST.fields_by_name['filter']._options = None
  _LISTCONNECTOROPERATIONSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _STARTCONNECTORREQUEST.fields_by_name['connector_id']._options = None
  _STARTCONNECTORREQUEST.fields_by_name['connector_id']._serialized_options = b'\350\3071\001'
  _STARTCONNECTORMETADATA.fields_by_name['connector_id']._options = None
  _STARTCONNECTORMETADATA.fields_by_name['connector_id']._serialized_options = b'\350\3071\001'
  _STOPCONNECTORREQUEST.fields_by_name['connector_id']._options = None
  _STOPCONNECTORREQUEST.fields_by_name['connector_id']._serialized_options = b'\350\3071\001'
  _STOPCONNECTORMETADATA.fields_by_name['connector_id']._options = None
  _STOPCONNECTORMETADATA.fields_by_name['connector_id']._serialized_options = b'\350\3071\001'
  _CONNECTORSERVICE.methods_by_name['Get']._options = None
  _CONNECTORSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002+\022)/eventrouter/v1/connectors/{connector_id}'
  _CONNECTORSERVICE.methods_by_name['List']._options = None
  _CONNECTORSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\034\022\032/eventrouter/v1/connectors'
  _CONNECTORSERVICE.methods_by_name['Create']._options = None
  _CONNECTORSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*$\n\027CreateConnectorMetadata\022\tConnector\202\323\344\223\002\037\"\032/eventrouter/v1/connectors:\001*'
  _CONNECTORSERVICE.methods_by_name['Update']._options = None
  _CONNECTORSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*$\n\027UpdateConnectorMetadata\022\tConnector\202\323\344\223\002.2)/eventrouter/v1/connectors/{connector_id}:\001*'
  _CONNECTORSERVICE.methods_by_name['Delete']._options = None
  _CONNECTORSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*0\n\027DeleteConnectorMetadata\022\025google.protobuf.Empty\202\323\344\223\002+*)/eventrouter/v1/connectors/{connector_id}'
  _CONNECTORSERVICE.methods_by_name['Start']._options = None
  _CONNECTORSERVICE.methods_by_name['Start']._serialized_options = b'\262\322*/\n\026StartConnectorMetadata\022\025google.protobuf.Empty\202\323\344\223\0021\"//eventrouter/v1/connectors/{connector_id}:start'
  _CONNECTORSERVICE.methods_by_name['Stop']._options = None
  _CONNECTORSERVICE.methods_by_name['Stop']._serialized_options = b'\262\322*.\n\025StopConnectorMetadata\022\025google.protobuf.Empty\202\323\344\223\0020\"./eventrouter/v1/connectors/{connector_id}:stop'
  _CONNECTORSERVICE.methods_by_name['ListAccessBindings']._options = None
  _CONNECTORSERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002=\022;/eventrouter/v1/connectors/{resource_id}:listAccessBindings'
  _CONNECTORSERVICE.methods_by_name['SetAccessBindings']._options = None
  _CONNECTORSERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002?\":/eventrouter/v1/connectors/{resource_id}:setAccessBindings:\001*'
  _CONNECTORSERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _CONNECTORSERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002B2=/eventrouter/v1/connectors/{resource_id}:updateAccessBindings:\001*'
  _CONNECTORSERVICE.methods_by_name['ListOperations']._options = None
  _CONNECTORSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0026\0224/eventrouter/v1/connectors/{connector_id}/operations'
  _globals['_GETCONNECTORREQUEST']._serialized_start=365
  _globals['_GETCONNECTORREQUEST']._serialized_end=414
  _globals['_LISTCONNECTORSREQUEST']._serialized_start=417
  _globals['_LISTCONNECTORSREQUEST']._serialized_end=556
  _globals['_LISTCONNECTORSRESPONSE']._serialized_start=558
  _globals['_LISTCONNECTORSRESPONSE']._serialized_end=678
  _globals['_CREATECONNECTORREQUEST']._serialized_start=681
  _globals['_CREATECONNECTORREQUEST']._serialized_end=1102
  _globals['_CREATECONNECTORREQUEST_LABELSENTRY']._serialized_start=1057
  _globals['_CREATECONNECTORREQUEST_LABELSENTRY']._serialized_end=1102
  _globals['_CREATECONNECTORMETADATA']._serialized_start=1104
  _globals['_CREATECONNECTORMETADATA']._serialized_end=1167
  _globals['_UPDATECONNECTORREQUEST']._serialized_start=1170
  _globals['_UPDATECONNECTORREQUEST']._serialized_end=1582
  _globals['_UPDATECONNECTORREQUEST_LABELSENTRY']._serialized_start=1057
  _globals['_UPDATECONNECTORREQUEST_LABELSENTRY']._serialized_end=1102
  _globals['_UPDATECONNECTORMETADATA']._serialized_start=1584
  _globals['_UPDATECONNECTORMETADATA']._serialized_end=1637
  _globals['_DELETECONNECTORREQUEST']._serialized_start=1639
  _globals['_DELETECONNECTORREQUEST']._serialized_end=1691
  _globals['_DELETECONNECTORMETADATA']._serialized_start=1693
  _globals['_DELETECONNECTORMETADATA']._serialized_end=1746
  _globals['_LISTCONNECTOROPERATIONSREQUEST']._serialized_start=1749
  _globals['_LISTCONNECTOROPERATIONSREQUEST']._serialized_end=1899
  _globals['_LISTCONNECTOROPERATIONSRESPONSE']._serialized_start=1901
  _globals['_LISTCONNECTOROPERATIONSRESPONSE']._serialized_end=2014
  _globals['_STARTCONNECTORREQUEST']._serialized_start=2016
  _globals['_STARTCONNECTORREQUEST']._serialized_end=2067
  _globals['_STARTCONNECTORMETADATA']._serialized_start=2069
  _globals['_STARTCONNECTORMETADATA']._serialized_end=2121
  _globals['_STOPCONNECTORREQUEST']._serialized_start=2123
  _globals['_STOPCONNECTORREQUEST']._serialized_end=2173
  _globals['_STOPCONNECTORMETADATA']._serialized_start=2175
  _globals['_STOPCONNECTORMETADATA']._serialized_end=2226
  _globals['_CONNECTORSERVICE']._serialized_start=2229
  _globals['_CONNECTORSERVICE']._serialized_end=4525
# @@protoc_insertion_point(module_scope)
